module.exports = defineTest({
	description: 'exports default-as-named from sibling module (b)'
});
